==> haskell-base-orphans-0.9.3-74.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base-orphans
version:              0.9.3
visibility:           public
id:                   base-orphans-0.9.3-HOf1XWEi853HRMMLyvb6TR
key:                  base-orphans-0.9.3-HOf1XWEi853HRMMLyvb6TR
license:              MIT
copyright:
    (c) 2012-2017 Simon Hengel,
    (c) 2014-2017 João Cristóvão,
    (c) 2015-2017 Ryan Scott

maintainer:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

homepage:             https://github.com/haskell-compat/base-orphans#readme
synopsis:             Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in
    later versions of @base@ to a wider (older) range of compilers.
    @base-orphans@ does not export anything except the orphan instances
    themselves and complements @<http://hackage.haskell.org/package/base-compat
    base-compat>@.

    See the README for what instances are covered:
    <https://github.com/haskell-compat/base-orphans#readme>.
    See also the
    <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered>
    section.

category:             Compatibility
abi:                  0798e0a3cf0941c907a018ad8b56c760
exposed:              True
exposed-modules:      Data.Orphans
hidden-modules:       Data.Orphans.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/base-orphans-0.9.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/base-orphans-0.9.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/base-orphans-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-orphans
hs-libraries:         HSbase-orphans-0.9.3-HOf1XWEi853HRMMLyvb6TR
depends:              base-4.17.2.1 ghc-prim-0.9.1
haddock-interfaces:
    /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock

haddock-html:         /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.9.3-86.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base-orphans
version:              0.9.3
visibility:           public
id:                   base-orphans-0.9.3-Dv0WmqG0V8uKpsjClS5qBn
key:                  base-orphans-0.9.3-Dv0WmqG0V8uKpsjClS5qBn
license:              MIT
copyright:
    (c) 2012-2017 Simon Hengel,
    (c) 2014-2017 João Cristóvão,
    (c) 2015-2017 Ryan Scott

maintainer:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

homepage:             https://github.com/haskell-compat/base-orphans#readme
synopsis:             Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in
    later versions of @base@ to a wider (older) range of compilers.
    @base-orphans@ does not export anything except the orphan instances
    themselves and complements @<http://hackage.haskell.org/package/base-compat
    base-compat>@.

    See the README for what instances are covered:
    <https://github.com/haskell-compat/base-orphans#readme>.
    See also the
    <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered>
    section.

category:             Compatibility
abi:                  6eff898a6f1520e75570b358aec85576
exposed:              True
exposed-modules:      Data.Orphans
hidden-modules:       Data.Orphans.Prelude
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/base-orphans-0.9.3
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/base-orphans-0.9.3
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/base-orphans-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-orphans
hs-libraries:         HSbase-orphans-0.9.3-Dv0WmqG0V8uKpsjClS5qBn
depends:              base-4.18.3.0 ghc-prim-0.10.0
haddock-interfaces:
    /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock

haddock-html:         /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
